==> spine_flutter-4.1.9.tar.gz: src/spine-cpp/include/spine/TransformConstraint.h <==
/******************************************************************************
 * Spine Runtimes License Agreement
 * Last updated July 28, 2023. Replaces all prior versions.
 *
 * Copyright (c) 2013-2023, Esoteric Software LLC
 *
 * Integration of the Spine Runtimes into software or otherwise creating
 * derivative works of the Spine Runtimes is permitted under the terms and
 * conditions of Section 2 of the Spine Editor License Agreement:
 * http://esotericsoftware.com/spine-editor-license
 *
 * Otherwise, it is permitted to integrate the Spine Runtimes into software or
 * otherwise create derivative works of the Spine Runtimes (collectively,
 * "Products"), provided that each user of the Products must obtain their own
 * Spine Editor license and redistribution of the Products in any form must
 * include this license and copyright notice.
 *
 * THE SPINE RUNTIMES ARE PROVIDED BY ESOTERIC SOFTWARE LLC "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL ESOTERIC SOFTWARE LLC BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES,
 * BUSINESS INTERRUPTION, OR LOSS OF USE, DATA, OR PROFITS) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THE
 * SPINE RUNTIMES, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#ifndef Spine_TransformConstraint_h
#define Spine_TransformConstraint_h

#include <spine/ConstraintData.h>

#include <spine/Vector.h>

namespace spine {
	class TransformConstraintData;

	class Skeleton;

	class Bone;

	class SP_API TransformConstraint : public Updatable {
		friend class Skeleton;

		friend class TransformConstraintTimeline;

	RTTI_DECL

	public:
		TransformConstraint(TransformConstraintData &data, Skeleton &skeleton);

		virtual void update();

		virtual int getOrder();

		TransformConstraintData &getData();

		Vector<Bone *> &getBones();

		Bone *getTarget();

		void setTarget(Bone *inValue);

		float getMixRotate();

		void setMixRotate(float inValue);

		float getMixX();

		void setMixX(float inValue);

		float getMixY();

		void setMixY(float inValue);

		float getMixScaleX();

		void setMixScaleX(float inValue);

		float getMixScaleY();

		void setMixScaleY(float inValue);

		float getMixShearY();

		void setMixShearY(float inValue);

		bool isActive();

		void setActive(bool inValue);

	private:
		TransformConstraintData &_data;
		Vector<Bone *> _bones;
		Bone *_target;
		float _mixRotate, _mixX, _mixY, _mixScaleX, _mixScaleY, _mixShearY;
		bool _active;

		void applyAbsoluteWorld();

		void applyRelativeWorld();

		void applyAbsoluteLocal();

		void applyRelativeLocal();
	};
}

#endif /* Spine_TransformConstraint_h */

==> spine_flutter-4.2.23.tar.gz: src/spine-cpp/include/spine/TransformConstraint.h <==
/******************************************************************************
 * Spine Runtimes License Agreement
 * Last updated July 28, 2023. Replaces all prior versions.
 *
 * Copyright (c) 2013-2023, Esoteric Software LLC
 *
 * Integration of the Spine Runtimes into software or otherwise creating
 * derivative works of the Spine Runtimes is permitted under the terms and
 * conditions of Section 2 of the Spine Editor License Agreement:
 * http://esotericsoftware.com/spine-editor-license
 *
 * Otherwise, it is permitted to integrate the Spine Runtimes into software or
 * otherwise create derivative works of the Spine Runtimes (collectively,
 * "Products"), provided that each user of the Products must obtain their own
 * Spine Editor license and redistribution of the Products in any form must
 * include this license and copyright notice.
 *
 * THE SPINE RUNTIMES ARE PROVIDED BY ESOTERIC SOFTWARE LLC "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL ESOTERIC SOFTWARE LLC BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES,
 * BUSINESS INTERRUPTION, OR LOSS OF USE, DATA, OR PROFITS) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THE
 * SPINE RUNTIMES, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#ifndef Spine_TransformConstraint_h
#define Spine_TransformConstraint_h

#include <spine/ConstraintData.h>

#include <spine/Vector.h>

namespace spine {
	class TransformConstraintData;

	class Skeleton;

	class Bone;

	class SP_API TransformConstraint : public Updatable {
		friend class Skeleton;

		friend class TransformConstraintTimeline;

	RTTI_DECL

	public:
		TransformConstraint(TransformConstraintData &data, Skeleton &skeleton);

		virtual void update(Physics physics);

		virtual int getOrder();

		TransformConstraintData &getData();

		Vector<Bone *> &getBones();

		Bone *getTarget();

		void setTarget(Bone *inValue);

		float getMixRotate();

		void setMixRotate(float inValue);

		float getMixX();

		void setMixX(float inValue);

		float getMixY();

		void setMixY(float inValue);

		float getMixScaleX();

		void setMixScaleX(float inValue);

		float getMixScaleY();

		void setMixScaleY(float inValue);

		float getMixShearY();

		void setMixShearY(float inValue);

		bool isActive();

		void setActive(bool inValue);

        void setToSetupPose();

	private:
		TransformConstraintData &_data;
		Vector<Bone *> _bones;
		Bone *_target;
		float _mixRotate, _mixX, _mixY, _mixScaleX, _mixScaleY, _mixShearY;
		bool _active;

		void applyAbsoluteWorld();

		void applyRelativeWorld();

		void applyAbsoluteLocal();

		void applyRelativeLocal();
	};
}

#endif /* Spine_TransformConstraint_h */
